tests Package
=============

:mod:`test_search` Module
-------------------------

.. automodule:: CMFDefault.browser.search.tests.test_search
    :members:
    :undoc-members:
    :show-inheritance:

